@@ -1,6 +1,6 @@
 import requests
 
-from exceptions import CamaraAPIException
+from sdk_dados_abertos_camara.exceptions import CamaraAPIException
 
 BASE_URL = 'https://dadosabertos.camara.leg.br/api/v2/'
 HEADERS = {
@@ -21,11 +21,11 @@ def get_one(endpoint, data_only=True):
 
 
 def get(endpoint,
+        extra_params={},
         order=None,
         orderBy=None,
         page=1,
         itens=20,
-        extra_params={},
         data_only=True):
     """
     Get a list of entities from an endpoint, e.g. /deputados
